@@ -51,7 +51,6 @@ namespace chart
 {
 //.............................................................................
 using namespace ::com::sun::star;
-//using namespace ::com::sun::star::chart2;
 
 namespace
 {
@@ -152,7 +151,7 @@ void Selection::remindSelectionBeforeMouseDown()
     m_aSelectedOID_beforeMouseDown = m_aSelectedOID;
 }
 
-bool Selection::isSelectionDifferentFromBeforeMouseDown()
+bool Selection::isSelectionDifferentFromBeforeMouseDown() const
 {
     return ( m_aSelectedOID != m_aSelectedOID_beforeMouseDown );
 }
@@ -277,10 +276,11 @@ void Selection::adaptSelectionToNewPos( const Point& rMousePos, DrawViewWrapper*
                 }
 
                 //check wether the diagram was hit but not selected (e.g. because it has no filling):
+                rtl::OUString aDiagramCID = ObjectIdentifier::createClassifiedIdentifier( OBJECTTYPE_DIAGRAM, rtl::OUString::valueOf( sal_Int32(0) ) );
                 rtl::OUString aWallCID( ObjectIdentifier::createClassifiedIdentifier( OBJECTTYPE_DIAGRAM_WALL, rtl::OUString() ) );//@todo read CID from model
-                if ( m_aSelectedOID.getObjectCID().equals( aPageCID ) || m_aSelectedOID.getObjectCID().equals( aWallCID ) || !m_aSelectedOID.isAutoGeneratedObject() )
+                bool bBackGroundHit = m_aSelectedOID.getObjectCID().equals( aPageCID ) || m_aSelectedOID.getObjectCID().equals( aWallCID ) || !m_aSelectedOID.isAutoGeneratedObject();
+                if( bBackGroundHit )
                 {
-                    rtl::OUString aDiagramCID = ObjectIdentifier::createClassifiedIdentifier( OBJECTTYPE_DIAGRAM, rtl::OUString::valueOf( sal_Int32(0) ) );
                     //todo: if more than one diagram is available in future do chack the list of all diagrams here
                     SdrObject* pDiagram = pDrawViewWrapper->getNamedSdrObject( aDiagramCID );
                     if( pDiagram )
@@ -292,6 +292,20 @@ void Selection::adaptSelectionToNewPos( const Point& rMousePos, DrawViewWrapper*
                         }
                     }
                 }
+                //check wether the legend was hit but not selected (e.g. because it has no filling):
+                if( bBackGroundHit || m_aSelectedOID.getObjectCID().equals( aDiagramCID ) )
+                {
+                    rtl::OUString aLegendCID( ObjectIdentifier::createClassifiedIdentifierForParticle( ObjectIdentifier::createParticleForLegend(0,0) ) );//@todo read CID from model
+                    SdrObject* pLegend = pDrawViewWrapper->getNamedSdrObject( aLegendCID );
+                    if( pLegend )
+                    {
+                        if( pDrawViewWrapper->IsObjectHit( pLegend, rMousePos ) )
+                        {
+                            m_aSelectedOID = ObjectIdentifier( aLegendCID );
+                            pNewObj = pLegend;
+                        }
+                    }
+                }
             }
         }
 
@@ -310,6 +324,7 @@ bool Selection::isResizeableObjectSelected()
         case OBJECTTYPE_DIAGRAM:
         case OBJECTTYPE_DIAGRAM_WALL:
         case OBJECTTYPE_SHAPE:
+        case OBJECTTYPE_LEGEND:
             return true;
         default:
             return false;
@@ -335,8 +350,6 @@ bool Selection::isAdditionalShapeSelected() const
 //-----------------------------------------------------------------------------
 //-----------------------------------------------------------------------------
 //-----------------------------------------------------------------------------
-
-//static
 bool SelectionHelper::findNamedParent( SdrObject*& pInOutObject
                                       , rtl::OUString& rOutName
                                       , bool bGivenObjectMayBeResult )
@@ -370,7 +383,6 @@ bool SelectionHelper::findNamedParent( SdrObject*& pInOutObject
     return true;
 }
 
-//static
 bool SelectionHelper::findNamedParent( SdrObject*& pInOutObject
                                       , ObjectIdentifier& rOutObject
                                       , bool bGivenObjectMayBeResult )
@@ -384,7 +396,6 @@ bool SelectionHelper::findNamedParent( SdrObject*& pInOutObject
     return false;
 }
 
-//static
 bool SelectionHelper::isDragableObjectHitTwice( const Point& rMPos
                     , const rtl::OUString& rNameOfSelectedObject
                     , const DrawViewWrapper& rDrawViewWrapper )
@@ -400,7 +411,6 @@ bool SelectionHelper::isDragableObjectHitTwice( const Point& rMPos
     return true;
 }
 
-// static
 ::rtl::OUString SelectionHelper::getHitObjectCID(
     const Point& rMPos,
     DrawViewWrapper& rDrawViewWrapper,
@@ -466,7 +476,6 @@ bool SelectionHelper::isDragableObjectHitTwice( const Point& rMPos
     // \\- solar mutex
 }
 
-//static
 bool SelectionHelper::isRotateableObject( const ::rtl::OUString& rCID
                     , const uno::Reference< frame::XModel >& xChartModel )
 {
@@ -489,7 +498,6 @@ SelectionHelper::~SelectionHelper()
 {
 }
 
-//virtual
 bool SelectionHelper::getFrameDragSingles()
 {
     bool bFrameDragSingles = true;//true == green == surrounding handles
@@ -498,7 +506,6 @@ bool SelectionHelper::getFrameDragSingles()
     return bFrameDragSingles;
 }
 
-//static
 SdrObject* SelectionHelper::getMarkHandlesObject( SdrObject* pObj )
 {
     if(!pObj)
@@ -554,7 +561,6 @@ SdrObject* SelectionHelper::getObjectToMark()
     return m_pMarkObj;
 }
 
-//static
 E3dScene* SelectionHelper::getSceneToRotate( SdrObject* pObj )
 {
     //search wether the object or one of its children is a 3D object
@@ -591,7 +597,6 @@ E3dScene* SelectionHelper::getSceneToRotate( SdrObject* pObj )
 
 }
 
-//virtual
 bool SelectionHelper::getMarkHandles( SdrHdlList& rHdlList )
 {
     SolarMutexGuard aSolarGuard;
